@@ -31,6 +31,8 @@ class KITINERARY_EXPORT PdfPage
     Q_PROPERTY(QString text READ text)
     Q_PROPERTY(QVariantList images READ imagesVariant)
     Q_PROPERTY(QVariantList links READ linksVariant)
+    Q_PROPERTY(int width READ width)
+    Q_PROPERTY(int height READ height)
 public:
     PdfPage();
     PdfPage(const PdfPage&);
@@ -68,6 +70,10 @@ public:
      */
     Q_INVOKABLE QVariantList linksInRect(double left, double top, double right, double bottom) const;
 
+    /** Page size in millimeters. */
+    int width() const;
+    int height() const;
+
 private:
     QVariantList imagesVariant() const;
     QVariantList linksVariant() const;
@@ -81,8 +87,6 @@ class PdfDocumentPrivate;
 
 /** PDF document for extraction.
  *  This is used as input for ExtractorEngine and the JS extractor scripts.
- *  @note This class is only functional if Poppler is available as a dependency,
- *  otherwise all methods return empty values.
  */
 class KITINERARY_EXPORT PdfDocument : public QObject
 {
@@ -92,6 +96,7 @@ class KITINERARY_EXPORT PdfDocument : public QObject
     Q_PROPERTY(QVariantList pages READ pagesVariant CONSTANT)
     Q_PROPERTY(QDateTime creationTime READ creationTime CONSTANT)
     Q_PROPERTY(QDateTime modificationTime READ modificationTime CONSTANT)
+    Q_PROPERTY(QString title READ title CONSTANT)
     Q_PROPERTY(QString producer READ producer CONSTANT)
 
 public:
@@ -115,6 +120,8 @@ public:
     /** Modification time as specified in the PDF file. */
     QDateTime modificationTime() const;
 
+    /** The document title. */
+    QString title() const;
     /** The document producer. */
     QString producer() const;
 
